((Drupal, once) => {
  'use strict';

  Drupal.behaviors.inboxFunctions = {
    attach: (context, settings) => {

      // Changing theme handler.
      const setTheme = (theme) => {
        if (theme === 'dark') {
          document.body.classList.add('theme-dark');
          document.querySelector('.theme-switcher-toggle .icon-night').classList.add('hidden');
          document.querySelector('.theme-switcher-toggle .icon-day').classList.remove('hidden');
          localStorage.setItem('theme', 'dark');
        } else {
          document.body.classList.remove('theme-dark');
          document.querySelector('.theme-switcher-toggle .icon-night').classList.remove('hidden');
          document.querySelector('.theme-switcher-toggle .icon-day').classList.add('hidden');
          localStorage.setItem('theme', 'light');
        }
      };

      // Theme switcher.
      const handleThemeSwitcherToggle = (e) => {
        e.stopPropagation();
        e.preventDefault();
        if (localStorage.getItem('theme') === 'light') {
          setTheme('dark');
        } else {
          setTheme('light');
        }
      };

      // Drawer.
      const handleDrawerToggle = (e) => {
        e.stopPropagation();
        e.preventDefault();
        document.body.classList.toggle('drawer-open');

        if (window.innerWidth > 992) {
          if (localStorage.getItem('drawer-open') === 'open') {
            localStorage.setItem('drawer-open', 'closed');
          } else {
            localStorage.setItem('drawer-open', 'open');
          }
        }
      };

      // Navbar search.
      const handleNavbarSearchOpen = (e) => {
        e.stopPropagation();
        e.preventDefault();
        document.body.classList.add('navbar-search-open');
        document.getElementById('edit-key').focus();
      };

      const handleNavbarSearchClose = () => {
        document.body.classList.remove('navbar-search-open');
      };

      once('navbarButtonActions', 'html').forEach(element => {
        if (localStorage.getItem('drawer-open') !== 'closed') {
          localStorage.setItem('drawer-open', 'open');
        }

        if (localStorage.getItem('theme') !== 'dark') {
          localStorage.setItem('theme', 'light');
        }

        // Adds 'drawer-open' class for wide screen.
        if (window.innerWidth > 992) {
          if (localStorage.getItem('drawer-open') === 'open') {
            document.body.classList.add('drawer-open');
          }
        }

        if (localStorage.getItem('theme') === 'dark') {
          setTheme('dark');
        }

        // Extend drawer toggle button default behavior.
        const navbarMenuToggle = document.getElementById('navbar-menu-toggle');
        navbarMenuToggle.addEventListener('click', handleDrawerToggle, true);

        // Navbar search.
        document.getElementById('navbar-search-toggle').addEventListener('click', handleNavbarSearchOpen);
        document.getElementById('edit-key').addEventListener('blur', handleNavbarSearchClose);

        // Theme switcher.
        document.querySelector('.theme-switcher-toggle').addEventListener('click', handleThemeSwitcherToggle);

        // Temporarily solution until https://www.drupal.org/node/2652000 is fixed.
        // Adds 'is-active' class to drawer menu links based on current path.
        document.querySelectorAll(`#drawer .menu a[href="${location.pathname}"]`).forEach(link => link.classList.add('is-active'));
      });

    }
  };
}) (Drupal, once);
